@@ -3,6 +3,9 @@ library(testthat)
 library(dplyr)
 library(compareDF)
 library(stringr)
+
+options(stringsAsFactors = FALSE)
+
 old_df = data.frame(var1 = c("A", "B", "C"),
                     val1 = c(1, 2, 3))
 
@@ -16,8 +19,8 @@ ctable = compare_df(new_df, old_df, c("var1"))
 expected_comparison_df = data.frame(var1 = ("C"), chng_type = c("+", "-"), val1 = c(4,3))
 expect_equal(expected_comparison_df[1,3], ctable$comparison_df[1,3])
 
-df1 <- data.frame(a = 1:5, b=letters[1:5], row = 1:5)
-df2 <- data.frame(a = 1:3, b=letters[1:3], row = 1:3)
+df1 <- data.frame(a = 1:5, b = letters[1:5], row = 1:5)
+df2 <- data.frame(a = 1:3, b = letters[1:3], row = 1:3)
 
 df_compare = compare_df(df1, df2, "row")
 expected_df = data.frame(row = c(4, 5), chng_type = "+", a = c(4, 5), b = c("d", "e"))
@@ -350,5 +353,22 @@ test_that("Uses generated row names as default if grouping column is provided",
     val1 = c(2, 3, 3)
   )
   compare_output = expect_warning(compare_df(new_df, old_df), "Missing grouping columns. Adding rownames to use as the default")
-  compare_output$comparison_df
+  expect_equivalent(compare_output$comparison_df, expected_output)
 })
+
+#===============================================================================
+context("compare_df: Works with Factors")
+options(stringsAsFactors = TRUE)
+
+test_that("Uses generated row names as default if grouping column is provided", {
+
+  df1 <- data.frame(a = 1:5, b = letters[1:5], row = 1:5)
+  df2 <- data.frame(a = 1:3, b = letters[1:3], row = 1:3)
+
+  df_compare = compare_df(df1, df2, "row")
+  expected_df = data.frame(row = c(4, 5), chng_type = "+", a = c(4, 5), b = c("d", "e"), stringsAsFactors = F)
+  expect_equivalent(df_compare$comparison_df, expected_df)
+})
+
+options(stringsAsFactors = FALSE)
+
